@@ -1,4 +1,5 @@
 import logging
+from collections import defaultdict
 from pathlib import Path
 
 import click
@@ -49,6 +50,16 @@ def create_config_dirs():
     config["CONFIG_PATH"].mkdir(parents=True, exist_ok=True)
 
 
+def _eval_branch(repo, branch):
+    """return default branch as fallback branch."""
+    if branch in repo.refs or f"origin/{branch}" in repo.refs:
+        return branch
+    elif "main" in repo.refs:
+        return "main"
+    else:
+        return "master"
+
+
 def download_pecha(pecha_id, out_path=None, needs_update=True, branch="main"):
     # clone the repo
     pecha_url = f"{config['OP_ORG']}/{pecha_id}.git"
@@ -61,6 +72,7 @@ def download_pecha(pecha_id, out_path=None, needs_update=True, branch="main"):
 
     if pecha_path.is_dir():  # if repo is already exits at local then try to pull
         repo = Repo(str(pecha_path))
+        branch = _eval_branch(repo, branch)
         repo.git.checkout(branch)
         if needs_update:
             click.echo(INFO.format(f"Updating {pecha_id} ..."))
@@ -73,6 +85,7 @@ def download_pecha(pecha_id, out_path=None, needs_update=True, branch="main"):
     except GitCommandError:
         raise PechaNotFound(f"Pecha with id {pecha_id} doesn't exist")
     repo = Repo(str(pecha_path))
+    branch = _eval_branch(repo, branch)
     repo.git.checkout(branch)
 
     return pecha_path
